==> haskell-nanospec-0.2.2-390-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-Dmz3XGGKwpnCXbtaPpMbAl
key:                  nanospec-0.2.2-Dmz3XGGKwpnCXbtaPpMbAl
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  720c80b6a266c9d0e71d74918d92a645
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nanospec
hs-libraries:         HSnanospec-0.2.2-Dmz3XGGKwpnCXbtaPpMbAl
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nanospec-0.2.2-391-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-BTosAwhAZUyElRHHOI0saR
key:                  nanospec-0.2.2-BTosAwhAZUyElRHHOI0saR
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  3bb289e8f8d64f549beba1ee997f21a8
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nanospec
hs-libraries:         HSnanospec-0.2.2-BTosAwhAZUyElRHHOI0saR
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
